@@ -36,7 +36,7 @@ MeasureDens = R6Class("MeasureDens",
       super$initialize(id,
         task_type = "dens", param_set = param_set, range = range, minimize = minimize,
         aggregator = aggregator, properties = properties, predict_type = predict_type,
-        task_properties = task_properties, packages = packages, man = man)
+        task_properties = task_properties, packages = c("mlr3proba", packages), man = man)
     }
   )
 )
