@@ -5,6 +5,6 @@ test_that("resample-step", {
   learner = mlr_learners$get("surv.coxph")
   resampling = rsmp("cv", folds = 3)
 
-  rr = resample(task, learner, resampling)
+  rr = suppressWarnings(resample(task, learner, resampling))
   expect_resample_result(rr)
 })
